############################################################################
#    Copyright (C) 2009 by Kushal Das                                      #
#    kushaldas@gmail.com                                                   #
#                                                                          #
#    This program is free software; you can redistribute it and#or modify  #
#    it under the terms of the GNU General Public License as published by  #
#    the Free Software Foundation; either version 2 of the License, or     #
#    (at your option) any later version.                                   #
#                                                                          #
#    This program is distributed in the hope that it will be useful,       #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
#    GNU General Public License for more details.                          #
#                                                                          #
#    You should have received a copy of the GNU General Public License     #
#    along with this program; if not, write to the                         #
#    Free Software Foundation, Inc.,                                       #
#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
############################################################################

from django.core.management import setup_environ
import settings

setup_environ(settings)


from django.db import models


class Disk(models.Model):
    """The disks"""
    name = models.TextField()


class Tags(models.Model):
    """All tags for disks"""
    tag_name = models.CharField(max_length=255)

class DiskByTag(models.Model):
    """
    Disk and tags
    """
    disk = models.ForeignKey(Disk)
    tag = models.ForeignKey(Tags)

class DiskFile(models.Model):
    """File on disk"""
    name = models.TextField()
    path = models.TextField()
    changetime = models.TextField()
    thumbnail = models.TextField()
    orientation = models.TextField()
    disk = models.ForeignKey(Disk, null=True)

class ExifData(models.Model):
    """EXIF Information"""
    diskfile = models.ForeignKey(DiskFile)
    make = models.TextField(null=True)
    model = models.TextField(null=True)
    orientation = models.TextField(null=True)
    exposure = models.TextField(null=True)
    fnumber = models.TextField(null=True)
    iso = models.TextField(null=True)
    exifversion = models.TextField(null=True)
    datetimeoriginal = models.DateTimeField(null=True)
    meteringmode = models.TextField(null=True)
    flash = models.TextField(null=True)
    focallength = models.TextField(null=True)
    comment = models.TextField(null=True)
    thumbnail = models.TextField(null=True)

class PhotoTags(models.Model):
    name = models.TextField()

class FileTags(models.Model):
    file = models.ForeignKey(DiskFile)
    tag = models.ForeignKey(PhotoTags)

class FlickrPhotoSet(models.Model):
    """Flickr Photo set"""
    title = models.TextField()
    set_id = models.TextField()
    thumbnail = models.TextField()
